import { 
  select, 
  csv,
	scaleOrdinal,
	pie,
	arc,
	sum} from 'd3';

const render = (data, selector) => {
  const width = 960;
	const height = 400;
	const radius = Math.min(width, height) / 2;
  
  const plot_container = select('.' + selector)
  	.append("div")
  	.attr("class", "helper_div")

 	const plotVariable = d => d.ARRIVAL_DELAY;
  
  const colorScale = scaleOrdinal()
  	.domain(['>15mins', '<15mins'])
  	.range(['#ff6309','#0277bd']);
  	// .range(['#3e3e97','#838690','#e56d26']); 
    // #ff6361
  
  const pie_calc = pie()
  	.value(plotVariable)(data);  
  
  const arc = d3.arc()
		.outerRadius(radius - 10)
		.innerRadius(radius - 125)
  	.padAngle([1/60]) // as angle is specified in radians
  	.cornerRadius([10]);

	const labelArc = d3.arc()
		.outerRadius(radius - 100)
		.innerRadius(radius - 40);
  
  const g = plot_container
  .append('svg')
  	.attr('width', width)
  	.attr('height', height)
  .selectAll('arc').append('g')
  	.data(pie_calc)
  	.enter().append('g')
  	.attr('transform', `translate(${width/2}, ${height/2})`)
  	.attr('class', 'pie-slice');
  
  g.append('path')
		.attr('d', arc)
		.style('fill', d => colorScale(d.data.ARRIVAL_DELAY_15));
  
  g.append('text')
  	.attr('transform', d => 
         `translate(${labelArc.centroid(d)})`)
    .text(d => d.data.ARRIVAL_DELAY_15)
  	.attr('class', 'dounat-text');
  
  g.on("mouseover", d => {
    
    let total = sum(data.map(plotVariable))
    
    let percent = Math.round(1000 * d.data.ARRIVAL_DELAY / total) / 10;
    
    d3.select('#tooltip')
        .style('left', d3.event.pageX + 'px')
        .style('top', d3.event.pageY + 'px')
        .style('opacity', 1)
        .select('#value')
        .text(percent);
	})
    g.on('mouseout', () => {
      // Hide the tooltip
      d3.select('#tooltip')
        .style('opacity', 0);
		});
  
  // prevent tooltip to disappear when hovered 
  select('#tooltip').
  	on('mouseover', () => {
  		select('#tooltip').style('opacity', 1)
  });
  
}

csv('https://gist.githubusercontent.com/josvin92/9a6b89cb9365b1042d6648fc584c3198/raw/Flight_Delay.csv').then(data => {
  data.forEach(d => {
    if(d.ARRIVAL_DELAY_15 == 1){
    		d.ARRIVAL_DELAY_15 = ">15 mins"; 
    }
    else if(d.ARRIVAL_DELAY_15 == 0){
    		d.ARRIVAL_DELAY_15 = "<15 mins"; 
    }
  	d.ARRIVAL_DELAY = +d.ARRIVAL_DELAY; 
			// console.log(d.DEPARTURE_DELAY);
  });
  
  const dataByDelay15 = d3.nest()
  	.key(function(d) {return d.ARRIVAL_DELAY_15;})
  	.rollup(function(v){return d3.sum(v, function(d) { return d.ARRIVAL_DELAY; });})
  	.entries(data)
  	.map(d => {
    	return {
        ARRIVAL_DELAY_15: d.key,
        ARRIVAL_DELAY: d.value}
      })
    
  // dataByDelay15.forEach(function(element) {
  //     console.log(element);
  //   });
// console.log(JSON.stringify(dataByDelay15));  
  render(dataByDelay15, 'plot_container');
});